summaryrefslogtreecommitdiffstats
path: root/core
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2021-10-31 00:13:21 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2021-10-31 00:14:22 +0900
commite8933e99b4600d91e9eab7d1ad3a2d35813028a9 (patch)
treeb2899fd1ef651a1bff56918ace94625a4bc14aa0 /core
parente8494e60efeb94c67c813d1c1c038031915e8c17 (diff)
downloadpolkit-tqt-e8933e99b4600d91e9eab7d1ad3a2d35813028a9.tar.gz
polkit-tqt-e8933e99b4600d91e9eab7d1ad3a2d35813028a9.zip
More Qt->TQt conversion and some clean up.
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'core')
-rw-r--r--core/CMakeLists.txt32
-rw-r--r--core/polkittqt1-actiondescription.cpp (renamed from core/polkitqt1-actiondescription.cpp)4
-rw-r--r--core/polkittqt1-actiondescription.h (renamed from core/polkitqt1-actiondescription.h)16
-rw-r--r--core/polkittqt1-authority.cpp (renamed from core/polkitqt1-authority.cpp)34
-rw-r--r--core/polkittqt1-authority.h (renamed from core/polkitqt1-authority.h)28
-rw-r--r--core/polkittqt1-details.cpp (renamed from core/polkitqt1-details.cpp)4
-rw-r--r--core/polkittqt1-details.h (renamed from core/polkitqt1-details.h)12
-rw-r--r--core/polkittqt1-identity.cpp (renamed from core/polkitqt1-identity.cpp)4
-rw-r--r--core/polkittqt1-identity.h (renamed from core/polkitqt1-identity.h)22
-rw-r--r--core/polkittqt1-subject.cpp (renamed from core/polkitqt1-subject.cpp)16
-rw-r--r--core/polkittqt1-subject.h (renamed from core/polkitqt1-subject.h)36
-rw-r--r--core/polkittqt1-temporaryauthorization.cpp (renamed from core/polkitqt1-temporaryauthorization.cpp)6
-rw-r--r--core/polkittqt1-temporaryauthorization.h (renamed from core/polkitqt1-temporaryauthorization.h)12
13 files changed, 113 insertions, 113 deletions
diff --git a/core/CMakeLists.txt b/core/CMakeLists.txt
index f2efca4de..feca7c96d 100644
--- a/core/CMakeLists.txt
+++ b/core/CMakeLists.txt
@@ -3,29 +3,29 @@ include_directories(
${CMAKE_CURRENT_SOURCE_DIR}
)
-set(polkit_qt_core_SRCS
- polkitqt1-authority.cpp
- polkitqt1-identity.cpp
- polkitqt1-subject.cpp
- polkitqt1-temporaryauthorization.cpp
- polkitqt1-details.cpp
- polkitqt1-actiondescription.cpp
+set(polkit_tqt_core_SRCS
+ polkittqt1-authority.cpp
+ polkittqt1-identity.cpp
+ polkittqt1-subject.cpp
+ polkittqt1-temporaryauthorization.cpp
+ polkittqt1-details.cpp
+ polkittqt1-actiondescription.cpp
)
-automoc4_add_library(polkit-qt-core-1 SHARED ${polkit_qt_core_SRCS})
+automoc4_add_library(polkit-tqt-core-1 SHARED ${polkit_tqt_core_SRCS})
-target_link_libraries(polkit-qt-core-1
- ${QT_QTCORE_LIBRARY}
- ${QT_QTDBUS_LIBRARY}
- ${QT_QTXML_LIBRARY}
+target_link_libraries(polkit-tqt-core-1
+ ${TQT_TQTCORE_LIBRARY}
+ ${TQT_TQTDBUS_LIBRARY}
+ ${TQT_TQTXML_LIBRARY}
${POLKIT_LIBRARIES}
${GLIB2_LIBRARIES}
${GOBJECT_LIBRARIES}
${GIO_LIBRARIES}
)
-set_target_properties(polkit-qt-core-1 PROPERTIES VERSION ${POLKITQT-1_LIBRARY_VERSION}
- SOVERSION ${POLKITQT-1_ABI_VERSION}
- DEFINE_SYMBOL MAKE_POLKITQT1_LIB)
+set_target_properties(polkit-tqt-core-1 PROPERTIES VERSION ${POLKITTQT-1_LIBRARY_VERSION}
+ SOVERSION ${POLKITTQT-1_ABI_VERSION}
+ DEFINE_SYMBOL MAKE_POLKITTQT1_LIB)
-install(TARGETS polkit-qt-core-1 ${INSTALL_TARGETS_DEFAULT_ARGS})
+install(TARGETS polkit-tqt-core-1 ${INSTALL_TARGETS_DEFAULT_ARGS})
diff --git a/core/polkitqt1-actiondescription.cpp b/core/polkittqt1-actiondescription.cpp
index 764510668..1cf9cf621 100644
--- a/core/polkitqt1-actiondescription.cpp
+++ b/core/polkittqt1-actiondescription.cpp
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
* Copyright (C) 2010 Dario Freddi <drf@kde.org>
*
@@ -19,7 +19,7 @@
* Boston, MA 02110-1301, USA.
*/
-#include "polkitqt1-actiondescription.h"
+#include "polkittqt1-actiondescription.h"
#include <TQtCore/TQString>
diff --git a/core/polkitqt1-actiondescription.h b/core/polkittqt1-actiondescription.h
index fac4812fb..666f3be67 100644
--- a/core/polkitqt1-actiondescription.h
+++ b/core/polkittqt1-actiondescription.h
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
* Copyright (C) 2010 Dario Freddi <drf@kde.org>
*
@@ -19,10 +19,10 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef POLKITQT1_ACTION_DESCRIPTION_H
-#define POLKITQT1_ACTION_DESCRIPTION_H
+#ifndef POLKITTQT1_ACTION_DESCRIPTION_H
+#define POLKITTQT1_ACTION_DESCRIPTION_H
-#include "polkitqt1-export.h"
+#include "polkittqt1-export.h"
#include <TQtCore/TQList>
#include <TQtCore/TQMetaType>
@@ -33,13 +33,13 @@ typedef struct _PolkitActionDescription PolkitActionDescription;
namespace PolkitTQt1
{
/**
- * \class ActionDescription polkitqt1-actiondescription.h ActionDescription
+ * \class ActionDescription polkittqt1-actiondescription.h ActionDescription
* \author Jaroslav Reznik <jreznik@redhat.com>
* \author Dario Freddi <drf@kde.org>
*
* \brief Class used to encapsulate a registered action.
*/
-class POLKITQT1_EXPORT ActionDescription
+class POLKITTQT1_EXPORT ActionDescription
{
public:
enum ImplicitAuthorization {
@@ -144,6 +144,6 @@ private:
};
}
-Q_DECLARE_METATYPE(PolkitTQt1::ActionDescription::List)
+TQ_DECLARE_METATYPE(PolkitTQt1::ActionDescription::List)
-#endif //POLKIT_QT_ACTION_DESCRIPTION_H
+#endif //POLKIT_TQT_ACTION_DESCRIPTION_H
diff --git a/core/polkitqt1-authority.cpp b/core/polkittqt1-authority.cpp
index d7cf300b8..8ec922d2e 100644
--- a/core/polkitqt1-authority.cpp
+++ b/core/polkittqt1-authority.cpp
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Daniel Nicoletti <dantti85-pk@yahoo.com.br>
* Copyright (C) 2009 Dario Freddi <drf@kde.org>
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
@@ -21,7 +21,7 @@
* Boston, MA 02110-1301, USA.
*/
-#include "polkitqt1-authority.h"
+#include "polkittqt1-authority.h"
#include <TQtDBus/TQDBusInterface>
#include <TQtDBus/TQDBusReply>
@@ -41,7 +41,7 @@ public:
Authority *q;
};
-Q_GLOBAL_STATIC(AuthorityHelper, s_globalAuthority)
+TQ_GLOBAL_STATIC(AuthorityHelper, s_globalAuthority)
Authority *Authority::instance(PolkitAuthority *authority)
{
@@ -178,11 +178,11 @@ void Authority::Private::init()
m_revokeTemporaryAuthorizationsCancellable = g_cancellable_new();
m_revokeTemporaryAuthorizationCancellable = g_cancellable_new();
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
GError *gerror = NULL;
#endif
if (pkAuthority == NULL) {
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
pkAuthority = polkit_authority_get_sync(NULL, &gerror);
if (gerror != NULL) {
setError(E_GetAuthority, gerror->message);
@@ -195,7 +195,7 @@ void Authority::Private::init()
}
if (pkAuthority == NULL) {
-#ifdef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifdef POLKIT_TQT_1_COMPATIBILITY_MODE
(E_GetAuthority);
#endif
return;
@@ -224,7 +224,7 @@ void Authority::Private::init()
TQList<TQString> seats;
qVariantValue<TQDBusArgument> (msg.arguments()[0]) >> seats;
// it can be multiple seats present so connect all their signals
- Q_FOREACH(const TQString &seat, seats) {
+ TQ_FOREACH(const TQString &seat, seats) {
seatSignalsConnect(seat);
}
}
@@ -262,7 +262,7 @@ void Authority::Private::dbusSignalAdd(const TQString &service, const TQString &
void Authority::Private::dbusFilter(const TQDBusMessage &message)
{
if (message.type() == TQDBusMessage::SignalMessage) {
- Q_EMIT q->consoleKitDBChanged();
+ TQ_EMIT q->consoleKitDBChanged();
// TODO: Test this with the multiseat support
if (message.member() == "SeatAdded") {
@@ -298,7 +298,7 @@ void Authority::clearError()
void Authority::Private::pk_config_changed()
{
- Q_EMIT Authority::instance()->configChanged();
+ TQ_EMIT Authority::instance()->configChanged();
}
PolkitAuthority *Authority::polkitAuthority() const
@@ -444,7 +444,7 @@ void Authority::Private::enumerateActionsCallback(GObject *object, GAsyncResult
return;
}
- Q_EMIT authority->enumerateActionsFinished(actionsToListAndFree(list));
+ TQ_EMIT authority->enumerateActionsFinished(actionsToListAndFree(list));
}
void Authority::enumerateActionsCancel()
@@ -516,7 +516,7 @@ void Authority::Private::registerAuthenticationAgentCallback(GObject *object, GA
return;
}
- Q_EMIT authority->registerAuthenticationAgentFinished(res);
+ TQ_EMIT authority->registerAuthenticationAgentFinished(res);
}
void Authority::registerAuthenticationAgentCancel()
@@ -588,7 +588,7 @@ void Authority::Private::unregisterAuthenticationAgentCallback(GObject *object,
return;
}
- Q_EMIT authority->unregisterAuthenticationAgentFinished(res);
+ TQ_EMIT authority->unregisterAuthenticationAgentFinished(res);
}
void Authority::unregisterAuthenticationAgentCancel()
@@ -659,7 +659,7 @@ void Authority::Private::authenticationAgentResponseCallback(GObject *object, GA
return;
}
- Q_EMIT authority->authenticationAgentResponseFinished(res);
+ TQ_EMIT authority->authenticationAgentResponseFinished(res);
}
void Authority::authenticationAgentResponseCancel()
@@ -720,7 +720,7 @@ void Authority::Private::enumerateTemporaryAuthorizationsCallback(GObject *objec
g_list_free(glist);
- Q_EMIT authority->enumerateTemporaryAuthorizationsFinished(res);
+ TQ_EMIT authority->enumerateTemporaryAuthorizationsFinished(res);
}
void Authority::enumerateTemporaryAuthorizationsCancel()
@@ -780,7 +780,7 @@ void Authority::Private::revokeTemporaryAuthorizationsCallback(GObject *object,
return;
}
- Q_EMIT authority->revokeTemporaryAuthorizationsFinished(res);
+ TQ_EMIT authority->revokeTemporaryAuthorizationsFinished(res);
}
void Authority::revokeTemporaryAuthorizationsCancel()
@@ -840,7 +840,7 @@ void Authority::Private::revokeTemporaryAuthorizationCallback(GObject *object, G
return;
}
- Q_EMIT authority->revokeTemporaryAuthorizationFinished(res);
+ TQ_EMIT authority->revokeTemporaryAuthorizationFinished(res);
}
void Authority::revokeTemporaryAuthorizationCancel()
@@ -852,4 +852,4 @@ void Authority::revokeTemporaryAuthorizationCancel()
}
-#include "polkitqt1-authority.moc"
+#include "polkittqt1-authority.moc"
diff --git a/core/polkitqt1-details.cpp b/core/polkittqt1-details.cpp
index 65d028b26..3175926c8 100644
--- a/core/polkitqt1-details.cpp
+++ b/core/polkittqt1-details.cpp
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Radek Novacek <rnovacek@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,7 +18,7 @@
* Boston, MA 02110-1301, USA.
*/
-#include "polkitqt1-details.h"
+#include "polkittqt1-details.h"
#include <TQtCore/TQStringList>
diff --git a/core/polkitqt1-details.h b/core/polkittqt1-details.h
index 2cb18163c..89e4e5b80 100644
--- a/core/polkitqt1-details.h
+++ b/core/polkittqt1-details.h
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Radek Novacek <rnovacek@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,10 +18,10 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef POLKITQT1_DETAILS_H
-#define POLKITQT1_DETAILS_H
+#ifndef POLKITTQT1_DETAILS_H
+#define POLKITTQT1_DETAILS_H
-#include "polkitqt1-export.h"
+#include "polkittqt1-export.h"
#include <TQtCore/TQObject>
#include <TQtCore/TQSharedData>
@@ -39,12 +39,12 @@ namespace PolkitTQt1
{
/**
- * \class Details polkitqt1-details.h Details
+ * \class Details polkittqt1-details.h Details
* \author Radek Novacek <rnovacek@redhat.com>
*
* \brief Class used for passing details around.
*/
-class POLKITQT1_EXPORT Details
+class POLKITTQT1_EXPORT Details
{
public:
/**
diff --git a/core/polkitqt1-identity.cpp b/core/polkittqt1-identity.cpp
index 1e03dda9a..8be2b55dc 100644
--- a/core/polkitqt1-identity.cpp
+++ b/core/polkittqt1-identity.cpp
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Lukas Tinkl <ltinkl@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,7 +18,7 @@
* Boston, MA 02110-1301, USA.
*/
-#include "polkitqt1-identity.h"
+#include "polkittqt1-identity.h"
#include <polkit/polkit.h>
diff --git a/core/polkitqt1-identity.h b/core/polkittqt1-identity.h
index e1f4dde90..600eba5e8 100644
--- a/core/polkitqt1-identity.h
+++ b/core/polkittqt1-identity.h
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Lukas Tinkl <ltinkl@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,10 +18,10 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef POLKITQT1_IDENTITY_H
-#define POLKITQT1_IDENTITY_H
+#ifndef POLKITTQT1_IDENTITY_H
+#define POLKITTQT1_IDENTITY_H
-#include "polkitqt1-export.h"
+#include "polkittqt1-export.h"
#include <unistd.h>
@@ -46,7 +46,7 @@ class UnixUserIdentity;
class UnixGroupIdentity;
/**
- * \class Identity polkitqt1-identity.h Identity
+ * \class Identity polkittqt1-identity.h Identity
* \author Lukas Tinkl <ltinkl@redhat.com>
*
* This class encapsulates the PolkitIdentity interface.
@@ -56,7 +56,7 @@ class UnixGroupIdentity;
* \see UnixGroup
* \see UnixUser
*/
-class POLKITQT1_EXPORT Identity
+class POLKITTQT1_EXPORT Identity
{
public:
typedef TQList< Identity > List;
@@ -107,14 +107,14 @@ private:
};
/**
- * \class UnixUserIdentity polkitqt1-identity.h Identity
+ * \class UnixUserIdentity polkittqt1-identity.h Identity
*
* An object representing a user identity on a UNIX system.
*
* \brief UNIX user identity
* \sa Identity
*/
-class POLKITQT1_EXPORT UnixUserIdentity : public Identity
+class POLKITTQT1_EXPORT UnixUserIdentity : public Identity
{
public:
UnixUserIdentity();
@@ -157,14 +157,14 @@ public:
};
/**
- * \class UnixGroupIdentity polkitqt1-identity.h Identity
+ * \class UnixGroupIdentity polkittqt1-identity.h Identity
*
* An object representing a group identity on a UNIX system.
*
* \brief UNIX group identity
* \sa Identity
*/
-class POLKITQT1_EXPORT UnixGroupIdentity : public Identity
+class POLKITTQT1_EXPORT UnixGroupIdentity : public Identity
{
public:
UnixGroupIdentity();
@@ -208,4 +208,4 @@ public:
}
-#endif // POLKIT_QT_IDENTITY_H
+#endif // POLKIT_TQT_IDENTITY_H
diff --git a/core/polkitqt1-subject.cpp b/core/polkittqt1-subject.cpp
index dea13d9f2..bafeaee56 100644
--- a/core/polkitqt1-subject.cpp
+++ b/core/polkittqt1-subject.cpp
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,7 +18,7 @@
* Boston, MA 02110-1301, USA.
*/
-#include "polkitqt1-subject.h"
+#include "polkittqt1-subject.h"
#include <TQtCore/TQDebug>
#include <polkit/polkit.h>
@@ -112,13 +112,13 @@ Subject Subject::fromString(const TQString &string)
return subject;
}
-UnixProcessSubject::UnixProcessSubject(qint64 pid)
+UnixProcessSubject::UnixProcessSubject(tqint64 pid)
: Subject()
{
setSubject(polkit_unix_process_new(pid));
}
-UnixProcessSubject::UnixProcessSubject(qint64 pid, tquint64 startTime)
+UnixProcessSubject::UnixProcessSubject(tqint64 pid, tquint64 startTime)
: Subject()
{
setSubject(polkit_unix_process_new_full(pid, startTime));
@@ -130,17 +130,17 @@ UnixProcessSubject::UnixProcessSubject(PolkitUnixProcess *pkUnixProcess)
}
-qint64 UnixProcessSubject::pid() const
+tqint64 UnixProcessSubject::pid() const
{
return polkit_unix_process_get_pid((PolkitUnixProcess *) subject());
}
-qint64 UnixProcessSubject::startTime() const
+tqint64 UnixProcessSubject::startTime() const
{
return polkit_unix_process_get_start_time((PolkitUnixProcess *) subject());
}
-void UnixProcessSubject::setPid(qint64 pid)
+void UnixProcessSubject::setPid(tqint64 pid)
{
polkit_unix_process_set_pid((PolkitUnixProcess *) subject(), pid);
}
@@ -175,7 +175,7 @@ UnixSessionSubject::UnixSessionSubject(const TQString &sessionId)
setSubject(polkit_unix_session_new(sessionId.toUtf8().data()));
}
-UnixSessionSubject::UnixSessionSubject(qint64 pid)
+UnixSessionSubject::UnixSessionSubject(tqint64 pid)
: Subject()
{
GError *error = NULL;
diff --git a/core/polkitqt1-subject.h b/core/polkittqt1-subject.h
index 25d986097..3f3b10279 100644
--- a/core/polkitqt1-subject.h
+++ b/core/polkittqt1-subject.h
@@ -1,5 +1,5 @@
/*
- * This file is part of the PolKit1-qt project
+ * This file is part of the PolKit1-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,10 +18,10 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef POLKITQT1_SUBJECT_H
-#define POLKITQT1_SUBJECT_H
+#ifndef POLKITTQT1_SUBJECT_H
+#define POLKITTQT1_SUBJECT_H
-#include "polkitqt1-export.h"
+#include "polkittqt1-export.h"
#include <TQtCore/TQObject>
#include <TQtCore/TQSharedData>
@@ -41,7 +41,7 @@ namespace PolkitTQt1
{
/**
- * \class Subject polkitqt1-subject.h Subject
+ * \class Subject polkittqt1-subject.h Subject
* \author Jaroslav Reznik <jreznik@redhat.com>
*
* \brief This class represents PolicyKit subjects
@@ -52,7 +52,7 @@ namespace PolkitTQt1
* \see SystemBusName
* \see UnixSession
*/
-class POLKITQT1_EXPORT Subject
+class POLKITTQT1_EXPORT Subject
{
public:
Subject();
@@ -99,7 +99,7 @@ private:
};
/**
- * \class UnixProcessSubject polkitqt1-subject.h Subject
+ * \class UnixProcessSubject polkittqt1-subject.h Subject
* \author Jaroslav Reznik <jreznik@redhat.com>
*
* \brief A class for representing a UNIX process.
@@ -111,7 +111,7 @@ private:
*
* \sa Subject
*/
-class POLKITQT1_EXPORT UnixProcessSubject : public Subject
+class POLKITTQT1_EXPORT UnixProcessSubject : public Subject
{
public:
/**
@@ -120,7 +120,7 @@ public:
*
* \param pid An Unix process PID.
*/
- explicit UnixProcessSubject(qint64 pid);
+ explicit UnixProcessSubject(tqint64 pid);
/**
* Subject constructor, takes two parameters - PID and start time.
@@ -128,7 +128,7 @@ public:
* \param pid An Unix process PID.
* \param startTime An Unix process start time.
*/
- UnixProcessSubject(qint64 pid, tquint64 startTime);
+ UnixProcessSubject(tqint64 pid, tquint64 startTime);
/**
* Subject constructor, it creates UnixProcess object from PolkitUnixProcess object
@@ -144,32 +144,32 @@ public:
*
* \return A PID of associated Unix process.
*/
- qint64 pid() const;
+ tqint64 pid() const;
/**
* Returns Unix process start time.
*
* \return A start time of associated Unix process.
*/
- qint64 startTime() const;
+ tqint64 startTime() const;
/**
* Sets Unix process PID.
*
* \param pid An Unix process PID.
*/
- void setPid(qint64 pid);
+ void setPid(tqint64 pid);
};
/**
- * \class SystemBusNameSubject polkitqt1-subject.h Subject
+ * \class SystemBusNameSubject polkittqt1-subject.h Subject
* \author Jaroslav Reznik <jreznik@redhat.com>
*
* \brief A class for representing a process owning a unique name on the system bus.
*
* \sa Subject
*/
-class POLKITQT1_EXPORT SystemBusNameSubject : public Subject
+class POLKITTQT1_EXPORT SystemBusNameSubject : public Subject
{
public:
/**
@@ -204,7 +204,7 @@ public:
};
/**
- * \class UnixSessionSubject polkitqt1-subject.h Subject
+ * \class UnixSessionSubject polkittqt1-subject.h Subject
* \author Jaroslav Reznik <jreznik@redhat.com>
*
* \brief A class for representing unix session.
@@ -214,7 +214,7 @@ public:
*
* \sa Subject
*/
-class POLKITQT1_EXPORT UnixSessionSubject : public Subject
+class POLKITTQT1_EXPORT UnixSessionSubject : public Subject
{
public:
/**
@@ -231,7 +231,7 @@ public:
*
* \param pid The session's process pid.
*/
- explicit UnixSessionSubject(qint64 pid);
+ explicit UnixSessionSubject(tqint64 pid);
/**
* Subject constructor, it creates UnixSession object from PolkitUnixSession object
diff --git a/core/polkitqt1-temporaryauthorization.cpp b/core/polkittqt1-temporaryauthorization.cpp
index 7614089d4..e0aa01871 100644
--- a/core/polkitqt1-temporaryauthorization.cpp
+++ b/core/polkittqt1-temporaryauthorization.cpp
@@ -1,5 +1,5 @@
/*
- * This file is part of the PolKit1-qt project
+ * This file is part of the PolKit1-tqt project
* Copyright (C) 2009 Radek Novacek <rnovacek@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,8 +18,8 @@
* Boston, MA 02110-1301, USA.
*/
-#include "polkitqt1-temporaryauthorization.h"
-#include "polkitqt1-authority.h"
+#include "polkittqt1-temporaryauthorization.h"
+#include "polkittqt1-authority.h"
#include <polkit/polkit.h>
diff --git a/core/polkitqt1-temporaryauthorization.h b/core/polkittqt1-temporaryauthorization.h
index 04deabb2c..8fbbaaa94 100644
--- a/core/polkitqt1-temporaryauthorization.h
+++ b/core/polkittqt1-temporaryauthorization.h
@@ -18,10 +18,10 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef POLKITQT1_TEMPORARYAUTHORIZATION_H
-#define POLKITQT1_TEMPORARYAUTHORIZATION_H
+#ifndef POLKITTQT1_TEMPORARYAUTHORIZATION_H
+#define POLKITTQT1_TEMPORARYAUTHORIZATION_H
-#include "polkitqt1-subject.h"
+#include "polkittqt1-subject.h"
#include <TQtCore/TQObject>
#include <TQtCore/TQDateTime>
@@ -41,14 +41,14 @@ namespace PolkitTQt1
{
/**
- * \class TemporaryAuthorization polkitqt1-temporaryauthorization.h TemporaryAuthorization
+ * \class TemporaryAuthorization polkittqt1-temporaryauthorization.h TemporaryAuthorization
* \author Radek Novacek <rnovacek@redhat.com>
*
* \brief This class represents PolicyKit temporary authorization
*
* This class encapsulates the PolkitTemporaryAuthorization interface.
*/
-class POLKITQT1_EXPORT TemporaryAuthorization
+class POLKITTQT1_EXPORT TemporaryAuthorization
{
public:
typedef TQList< TemporaryAuthorization > List;
@@ -119,6 +119,6 @@ private:
};
}
-Q_DECLARE_METATYPE(PolkitTQt1::TemporaryAuthorization::List)
+TQ_DECLARE_METATYPE(PolkitTQt1::TemporaryAuthorization::List)
#endif // TEMPORARYAUTHORIZATION_H
diff --git a/core/polkitqt1-authority.h b/core/polkittqt1-authority.h
index 6a0bb1f8e..6ced45ad6 100644
--- a/core/polkitqt1-authority.h
+++ b/core/polkittqt1-authority.h
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Daniel Nicoletti <dantti85-pk@yahoo.com.br>
* Copyright (C) 2009 Dario Freddi <drf@kde.org>
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
@@ -21,14 +21,14 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef POLKITQT1_AUTHORITY_H
-#define POLKITQT1_AUTHORITY_H
+#ifndef POLKITTQT1_AUTHORITY_H
+#define POLKITTQT1_AUTHORITY_H
-#include "polkitqt1-export.h"
-#include "polkitqt1-identity.h"
-#include "polkitqt1-subject.h"
-#include "polkitqt1-temporaryauthorization.h"
-#include "polkitqt1-actiondescription.h"
+#include "polkittqt1-export.h"
+#include "polkittqt1-identity.h"
+#include "polkittqt1-subject.h"
+#include "polkittqt1-temporaryauthorization.h"
+#include "polkittqt1-actiondescription.h"
#include <TQtCore/TQObject>
#include <TQtCore/TQMetaType>
@@ -47,7 +47,7 @@ namespace PolkitTQt1
{
/**
- * \class Authority polkitqt1-authority.h Authority
+ * \class Authority polkittqt1-authority.h Authority
* \author Daniel Nicoletti <dantti85-pk@yahoo.com.br>
* \author Dario Freddi <drf@kde.org>
* \author Jaroslav Reznik <jreznik@redhat.com>
@@ -63,7 +63,7 @@ namespace PolkitTQt1
* Call Authority::instance() to get an instance of the Authority object.
* Do not delete Authority::instance(), cleanup will be done automatically.
*/
-class POLKITQT1_EXPORT Authority : public TQObject
+class POLKITTQT1_EXPORT Authority : public TQObject
{
Q_OBJECT
TQ_DISABLE_COPY(Authority)
@@ -91,7 +91,7 @@ public:
* to block for a long time. **/
AllowUserInteraction = 0x01
};
- Q_DECLARE_FLAGS(AuthorizationFlags, AuthorizationFlag)
+ TQ_DECLARE_FLAGS(AuthorizationFlags, AuthorizationFlag)
/** Error codes for the authority class */
enum ErrorCode {
@@ -111,7 +111,7 @@ public:
E_RegisterFailed = 0x06,
/** Unregistration of authentication agent failed **/
E_UnregisterFailed = 0x07,
/** Cookie or polkitqt1-identity.handled to the action is empty **/
E_CookieOrIdentityEmpty = 0x08,
/** Response of auth agent failed **/
E_AgentResponseFailed = 0x09,
@@ -125,7 +125,7 @@ public:
* Returns the current instance of Authority. Call this function whenever
* you need to access the Authority class.
*
- * \note Authority is a singleton. Memory is handled by polkit-qt, so you just
+ * \note Authority is a singleton. Memory is handled by polkit-tqt, so you just
* need to call this function to get a working instance of Authority.
* Don't delete the object after having used it.
*
@@ -170,7 +170,7 @@ public:
/**
* Returns the current instance of PolkitAuthority. If you are handling
- * it through Polkit-qt (which is quite likely, since you are calling
+ * it through Polkit-tqt (which is quite likely, since you are calling
* this function), DO NOT use any PolicyKit API's specific method that
* modifies the instance on it, unless you're completely aware of what you're doing and
* of the possible consequencies. Use this instance only to gather information.
@@ -111,7 +111,7 @@ public:
/** Unregistration of authentication agent failed **/
E_UnregisterFailed = 0x07,
- /** Cookie or polkitqt1-identity.handled to the action is empty **/
+ /** Cookie or polkittqt1-identity.handled to the action is empty **/
E_CookieOrIdentityEmpty = 0x08,
/** Response of auth agent failed **/